@@ -30,7 +30,8 @@ class NameLenWarning(UserWarning):
 
 class CopyWarning(UserWarning):
     ''' Used if the user tries to call copy.copy on a NameSet,
-        since the NameSet's behavior of returning a deep copy in this case in contrary to how copy.copy usually works'''
+        since the NameSet's behavior of returning a deep copy in this case
+        is contrary to how copy.copy usually works.'''
     pass
 
 warnings.simplefilter('always', OrderWarning)
@@ -47,7 +48,8 @@ def get_rng():
 
 def set_rng(new_rng):
     ''' Sets a new global random number generator for this module.
-        new_rng must have a 'choice' method that takes in a list and returns one item from that list.'''
+        new_rng must have a 'choice' method that takes in a list
+        and returns one item from that list.'''
     global rng
     rng = new_rng
 
@@ -100,19 +102,24 @@ class NameSet():
         return type(other_set) is NameSet and self.__dict__ == other_set.__dict__
 
     def __iter__(self):
+        ''' Iterate over this NameSet's training data.'''
         return _NameSetIterator(self)
 
     def __len__(self):
+        ''' Length of this NameSet's training data.'''
         return len(self._names)
 
     def __getitem__(self, index):
+        ''' Gets the name at input index from this NameSet's training data.'''
         return self._names[index]
 
     def __contains__(self, item):
+        ''' True if the input item is in this NameSet's training data.'''
         return item in self._names_set
 
     def __add__(self, other_name_set):
-        ''' Adds two NameSets together using + operator and returns a new NameSet object.
+        ''' Adds two NameSets using + operator and returns a new NameSet object.
+            other_name_set can be a NameSet or any container of names.
             Duplicate names are counted twice.
             The returned NameSet has no history.'''
         copy_set = self.copy()
@@ -123,10 +130,13 @@ class NameSet():
         return copy_set
 
     def __iadd__(self, other_name_set):
-        ''' Modifies this data set and adds the new names to it, using the += operator.
-            Duplicate names are added again.  If duplicate names are not desired, use the |= operator.
+        ''' Modifies this data set and adds the new names to it,
+            using the += operator.
+            Duplicate names are added again.
+            If duplicate names are not desired, use the |= operator.
             other_name_set can be a NameSet or any container of names.
-            Keeps the order of this NameSet, even if other_name_set has a different order.
+            Keeps the order of this NameSet, even if other_name_set has a
+            different order.
             Does not modify this NameSet's history.'''
 
         if type(other_name_set) is str:
@@ -162,6 +172,7 @@ class NameSet():
 
     def __sub__(self, other_names):
         ''' Subtracts other_names from the NameSet using the - operator.
+            other_names can be a NameSet or any container of names.
             Returns a new NameSet object, and does not modify this one.
             The returned NameSet has no history.'''
         copy_set = self.copy()
@@ -209,7 +220,9 @@ class NameSet():
         return self
 
     def __or__(self, other_name_set):
-        ''' Union of this NameSet with another collection of names using the | operator.
+        ''' Union of this NameSet with another collection of names
+            using the | operator.
+            other_name_set can be a NameSet or any container of names.
             Does not modify this set, and returns a new NameSet object.
             Names are only counted once. All duplicates are removed.
             The returned NameSet has no history.'''
@@ -221,11 +234,14 @@ class NameSet():
         return copy_set
 
     def __ior__(self, other_name_set):
-        ''' Takes the union of this NameSet with another collection of names, using the |= operator.
-            Modifies this NameSet and does not return a new NameSet.
-            Each name is only counted once. ALL duplicates are removed from this NameSet.
+        ''' Takes the union of this NameSet with another collection of names,
+            using the |= operator.
+            Modifies this NameSet in place.
+            Each name is only counted once.
+            ALL duplicates are removed from this NameSet.
             other_name_set can be a NameSet or any container of names.
-            Keeps the order of this NameSet, even if other_name_set has a different order.
+            Keeps the order of this NameSet,
+            even if other_name_set has a different order.
             Does not modify this NameSet's history.'''
 
         if type(other_name_set) is str:
@@ -249,7 +265,9 @@ class NameSet():
         return self
 
     def __and__(self, other_name_set):
-        ''' Intersection of this NameSet with another collection of names using the & operator.
+        ''' Intersection of this NameSet with another collection of names
+            using the & operator.
+            other_name_set can be a NameSet or any container of names.
             Does not modify this set, and returns a new NameSet object.
             The returned NameSet has no history.'''
         copy_set = self.copy()
@@ -260,7 +278,9 @@ class NameSet():
         return copy_set
 
     def __iand__(self, other_name_set):
-        ''' Intersection of this NameSet with another collection of names using the &= operator.
+        ''' Intersection of this NameSet with another collection of names
+            using the &= operator.
+            other_name_set can be a NameSet or any container of names.
             Modifies this NameSet in place.
             Does not modify this NameSet's history.'''
 
@@ -334,7 +354,8 @@ class NameSet():
         self._avg_name_len = sum_lengths / len(self)
 
     def remove_duplicates(self):
-        ''' Removes any duplicated names from the NameSet so there is only one of each name.'''
+        ''' Removes any duplicated names from the NameSet so there is only one
+            of each name.'''
         names_set = set()
         for name in self._names[:]:
             if name in names_set:
@@ -358,11 +379,13 @@ class NameSet():
         self._update_avg_name_len()
 
     def get_order(self):
-        ''' Returns the Markov chain order of this NameSet.'''
+        ''' Returns the Markov chain order of this NameSet,
+            i.e. how many letters are used for matching.'''
         return self._order
 
     def get_name_len_func(self):
-        ''' Returns the function used to calculate the length of names in this NameSet.'''
+        ''' Returns the function used to calculate the length of names
+            in this NameSet.'''
         return self._name_len_func
 
     def get_avg_name_len(self):
@@ -377,7 +400,8 @@ class NameSet():
     def add_to_history(self, name_s):
         ''' Adds the input name or names to this NameSet's history.
             name_s can be a single name input as a string,
-            or a collection of names in the form of a NameSet, list, set, or other iterable.'''
+            or a collection of names in the form of a NameSet,
+            list, set, or other iterable.'''
         if type(name_s) is str:
             name_s = {name_s}
         self._history |= set(name_s)
@@ -433,20 +457,36 @@ class NameSet():
 
     def make_name(self, exclude_real_names = True, exclude_history = True, add_to_history = True,
                   n_candidates = DEFAULT_N_CANDIDATES, pref_candidate = AVG, max_attempts = DEFAULT_MAX_ATTEMPTS, validation_func = None):
-        ''' Creates and returns a name, or returns an empty string if name creation fails.
+        ''' Creates and returns a name,
+            or returns an empty string if name creation fails.
             INPUTS:
-            exclude_real_names: bool, prevents the creation of a name that's already in this NameSet if True.
-            exclude_history:    bool, prevents the creation of a name already in this NameSet's history if True.
-            add_to_history:     bool, adds the created name to the NameSet's history if True.
-            n_candidates:       int, number of name candidates to create. The best one (as determined by pref_candidate) is  returned.
-            pref_candidate:     The method used to pick the preferred name candidate. Possible values:
-                                MIN (0): Picks the candidate with the lowest value according to this NameSet's name_len_func.
-                                MAX (1): Picks the candidate with the highest value according to this NameSet's name_len_func.
-                                AVG (2): Picks the candidate that best agrees with the average name length of this NameSet's training data,
-                                         as measured by the NameSet's name_len_func.
-            max_attempts:       int, the maximum number of attempts (per name candidate) to make a valid name.
-            validation_func:    function or None, used to weed out invalid name candidates.
-                                Must take a single string as input and return True if it's a valid name, False otherwise.'''
+            exclude_real_names: bool, prevents the creation of a name that's
+                                already in this NameSet if True.
+            exclude_history:    bool, prevents the creation of a name already in
+                                this NameSet's history if True.
+            add_to_history:     bool, adds the created name to this NameSet's
+                                history if True.
+            n_candidates:       int, number of name candidates to create.
+                                The best one (as determined by pref_candidate)
+                                is  returned.
+            pref_candidate:     The method used to pick the preferred name
+                                candidate. Possible values:
+                                MIN (0): Picks the candidate with the lowest
+                                         value according to this
+                                         NameSet's name_len_func.
+                                MAX (1): Picks the candidate with the highest
+                                         value according to this
+                                         NameSet's name_len_func.
+                                AVG (2): Picks the candidate that best agrees
+                                         with the average name length of
+                                         this NameSet's training data,
+                                         as measured by the name_len_func.
+            max_attempts:       int, the maximum number of attempts
+                                (per name candidate) to make a valid name.
+            validation_func:    function or None, used to weed out invalid name
+                                candidates. Must take a single string as input
+                                and return True if it's a valid name,
+                                False otherwise.'''
 
         if validation_func is None:
             validation_func = _PASS_EVERYTHING
@@ -499,14 +539,21 @@ class _NameSetIterator():
 '=================================================================== User functions =========================================================='
 
 def make_name_set(names, order = DEFAULT_ORDER, name_len_func = DEFAULT_NAME_LEN_FUNC, clean_up = True):   # if changing deefault clean_up, also change in sample
-    ''' Creates and returns a NameSet object with the input names as training data.
+    ''' Creates and returns a NameSet object
+        with the input names as training data.
         INPUTS:
-        names:          Any collection of names, a NameSet, or the name of a file where names are stored.
-        order:          int, the order of the Markov chains that will be used to create random names.
-        name_len_func:  A function used to quantify the length, complexity, or any other interesting property of the names in a NameSet.
-                        Must take a single string as input and return a numerical value.
-        clean_up:       bool, determines if the names will be cleaned of messy data.
-                        If True, names will have any non-alphanumeric symbols removed from the start and end of the name,
+        names:          Any collection of names, a NameSet,
+                        or the name of a file where names are stored.
+        order:          int, the order of the Markov chains that will be used
+                        to create random names.
+                        I.E. how many letters are used for matching.
+        name_len_func:  A function used to quantify the length, complexity, or
+                        any other interesting property of the NameSet's names.
+                        Must take a single string as input and return a
+                        numerical value.
+        clean_up:       bool, determines if the names will be cleaned of messy
+                        data. If True, names will have any non-alphanumeric
+                        symbols removed from the start and end of the name,
                         and blank names will be removed.'''
     if type(names) is str:
         names = get_names_from_file(names)
@@ -518,7 +565,8 @@ def get_names_from_file(file_name):
     ''' Takes a file name as a string, with or without a file extension,
         and returns a list of names stored in that file.
         The file should be a text file with one name on each line.
-        If no file extension is included, this function assumes the extension is .txt'''
+        If no file extension is included,
+        this function assumes the extension is .txt'''
     def get_names(file_name, encoding):
         with open(file_name, 'r', encoding = encoding) as f:
             names = [line.strip('\n\r\t') for line in f.readlines()]    # get rid of any newline, carriage return, and tab characters
@@ -542,43 +590,49 @@ def get_built_in_names(file_name):
     if not file_name.endswith('.txt'):
         file_name += '.txt'
     name_bytes = pkgutil.get_data(__name__, file_name)
-    names = name_bytes.decode('utf-8').split('\n')                      # built-in name data will always be in utf-8 format
+    names = name_bytes.decode('utf-8').splitlines()                     # built-in name data will always be in utf-8 format
     return [n.strip('\n\r\t') for n in names]                           # get rid of any newline, carriage return, and tab characters
 
 def clean(names):
-    ''' Cleans extra symbols from the start or end of the names, and removes blank names.
+    ''' Cleans extra symbols from the start or end of the names,
+        and removes blank names.
         names can be any collection of names, including a NameSet.
         Returns a new list. The input object is not modified.'''
     return clean_blanks(clean_extra_symbols(names))
 
 def clean_blanks(names, blank_names = []):
-    ''' Removes empty names and names that consist of only non-alphanumeric characters.
+    ''' Removes empty names and names that consist
+        only of non-alphanumeric characters.
         Also removes any of the names in the input blank_names list.
         names can be any collection of names, including a NameSet.
         Returns a new list. The input object is not modified.'''
     return [n for n in names if strip_non_alnum(n) and n not in blank_names]
 
 def clean_extra_symbols(names):
-    ''' Removes non-alphanumeric characters from the beginning and end of each name,
-        in case the data source put extraneous symbols in to denote special meaning
-        (like wikipedia sometimes does).
+    ''' Removes non-alphanumeric characters from the beginning and end of each
+        name, in case the data source put extraneous symbols in to denote
+        special meaning (like wikipedia sometimes does).
         names can be any collection of names, including a NameSet.
         Returns a new list. The input object is not modified.'''
     return [strip_non_alnum(n) for n in names]
 
 def strip_non_alnum(string):
-    ''' Strips any non-alphanumeric characters from the beginning and end of the string.
-        Doesn't touch non-alphanumeric characters surrounded by alphanumeric characters.
+    ''' Strips any non-alphanumeric characters from the beginning
+        and end of the string.
+        Doesn't touch non-alphanumeric characters surrounded by
+        alphanumeric characters.
         Ex: '? Test-string 2!' becomes 'Test-string 2' '''
     strip_chars = ''.join([char for char in string if not char.isalnum()])
     return string.strip(strip_chars)
 
 def estimate_syllables(name):
     ''' Estimates the number of syllables in the input name.
-        This works by counting the number of alternations between consonants and vowels.
+        Works by counting alternations between consonants and vowels.
         Only an estimate, not necessarily accurate.
-        For reference, 'antidisestablishmentarianism' is 12 syllables and this function estimates it as 10.
-        'The quick brown fox jumped over the lazy dog.' is 11 and this functions estimates it as 12.'''
+        For reference, 'antidisestablishmentarianism' is 12 syllables
+        and this function estimates it as 10.
+        'The quick brown fox jumped over the lazy dog.'
+        is 11 and this function estimates it as 12.'''
     if not name:
         return 0
 
@@ -615,16 +669,23 @@ def estimate_syllables(name):
 
 def sample(names, n = 20, **kwargs):
     ''' Prints a sample of n names based on the input collection of names.
-        Uses the input **kwargs in make_name_set and in calls to NameSet.make_name.
-        The intent of this function is to get a quick idea of how different inputs affect the final result.
+        Uses the input **kwargs in make_name_set and in calls to
+        NameSet.make_name.
+        The intent of this function is to get a quick idea of how
+        different inputs affect the final result.
         It is not intended for use in production code.
-        Values specified in **kwargs are prioritized, followed by attributes of the input NameSet (if names is a NameSet), followed by default values.
-        This function operates on a copy of names, so the input list, set, or NameSet of names will not be modified.
+        Values specified in **kwargs are prioritized,
+        followed by attributes of the input NameSet (if names is a NameSet),
+        followed by default values.
+        This function operates on a copy of names,
+        so the input list, set, or NameSet of names will not be modified.
         
         INPUTS:
-        names:    Any collection of names, a NameSet, or the name of a file where names are stored.
+        names:    Any collection of names, a NameSet, or the name of a
+                  file where names are stored.
         n:        int, the number of samples to print.
-        **kwargs: Any keyword arguments that are accepted by make_name_set or NameSet.make_name'''
+        **kwargs: Any keyword arguments that are accepted by make_name_set or
+                  NameSet.make_name'''
     if type(names) is NameSet:
         if 'order' in kwargs and kwargs['order'] != names.get_order():      # message if kwargs conflicts with NameSet attributes
             print(f'Input NameSet has order {names.get_order()}, but input kwargs specified order {kwargs["order"]}. Using {kwargs["order"]}.')
@@ -652,15 +713,17 @@ def sample(names, n = 20, **kwargs):
         print(name_set.make_name(**kwargs))
 
 def is_clean(name, banned_words):
-    ''' Returns True if the name is clean, i.e. it does not contain any banned words.
+    ''' Returns True if the name is clean,
+        i.e. it does not contain any banned words.
         Returns False if there is a banned word in the name.
         Not case sensitive.
-        This function is called in NameSet.make_name with the module-level banned_words set
-        to make sure a name containing a banned word is not generated.
+        This function is called in NameSet.make_name with the module-level
+        banned_words set to make sure a name containing a banned word is
+        not generated.
 
         INPUTS:
         name:         A string.
-        banned_words: A collection of words that are not allowed to be in the name.'''
+        banned_words: A collection of words that are not allowed in name.'''
     casefolded_name = name.casefold()
     for word in banned_words:   # avoid using get_banned_words for performance reasons. No need to make a copy of the banned_words list for every name candidate
         if word.casefold() in casefolded_name:
